pub fn executor(
model: &Model,
ordinal: usize,
precision: Precision,
) -> Result<Executor<CudaBackend>>Expand description
The compat graph of model on GPU ordinal at precision, with the default bucket table.
Errors
kime_tensor::Error::Device when the GPU cannot be opened, or an error from lowering, which
for a checkpoint that loaded means a bug.